"Main interface for resourcegroupstaggingapi service"

from mypy_boto3_resourcegroupstaggingapi.client import Client
from mypy_boto3_resourcegroupstaggingapi.helpers import boto3_client


__all__ = ("Client", "boto3_client")
